@@ -8,7 +8,9 @@ from dateutil import rrule
 from itertools import groupby
 from cached_property import cached_property
 
+from trytond.i18n import gettext
 from trytond.model import Workflow, ModelSQL, ModelView, fields, Unique
+from trytond.model.exceptions import AccessError
 from trytond.pyson import Eval, Bool, If
 from trytond.pool import Pool
 from trytond.transaction import Transaction
@@ -173,11 +175,8 @@ class Asset(Workflow, ModelSQL, ModelView):
         table = cls.__table__()
         cls._sql_constraints = [
             ('invoice_line_uniq', Unique(table, table.supplier_invoice_line),
-                'Supplier Invoice Line can be used only once on asset.'),
+                'account_asset.msg_asset_invoice_line_unique'),
             ]
-        cls._error_messages.update({
-                'delete_draft': 'Asset "%s" must be in draft to be deleted.',
-                })
         cls._transitions |= set((
                 ('draft', 'running'),
                 ('running', 'closed'),
@@ -622,7 +621,6 @@ class Asset(Workflow, ModelSQL, ModelView):
         else:
             default = default.copy()
         default.setdefault('lines', [])
-        default.setdefault('update_moves', [])
         default.setdefault('number', None)
         default.setdefault('supplier_invoice_line', None)
         default.setdefault('move')
@@ -632,7 +630,9 @@ class Asset(Workflow, ModelSQL, ModelView):
     def delete(cls, assets):
         for asset in assets:
             if asset.state != 'draft':
-                cls.raise_user_error('delete_draft', asset.rec_name)
+                raise AccessError(
+                    gettext('account_asset.msg_delete_draft',
+                        asset=asset.rec_name))
         return super(Asset, cls).delete(assets)
 
 
@@ -710,8 +710,8 @@ class UpdateAssetShowDepreciation(ModelView):
     amount = fields.Numeric('Amount', readonly=True)
     date = fields.Date('Date', required=True,
         domain=[
-            ('date', '>=', Eval('latest_move_date')),
-            ('date', '<=', Eval('next_depreciation_date')),
+            ('date', '>', Eval('latest_move_date')),
+            ('date', '<', Eval('next_depreciation_date')),
             ],
         depends=['latest_move_date', 'next_depreciation_date'],
         help=('The date must be between the last update/depreciation date '
@@ -820,7 +820,7 @@ class UpdateAsset(Wizard):
         asset = Asset(Transaction().context['active_id'])
         latest_move_date = self.show_move.latest_move_date
         next_date = self.show_move.next_depreciation_date
-        if not (latest_move_date <= self.show_move.date <= next_date):
+        if not (latest_move_date < self.show_move.date < next_date):
             raise ValueError('The update move date is invalid')
         move = self.get_move(asset)
         move.lines = self.get_move_lines(asset)
@@ -896,10 +896,7 @@ class AssetDepreciationTable(CompanyReport):
             'closing_value',
             }
         for attr_name in grouped_attributes:
-            descr = cached_property(adder(attr_name))
-            setattr(Grouper, attr_name, descr)
-            if hasattr(descr, '__set_name__'):
-                descr.__set_name__(Grouper, attr_name)
+            setattr(Grouper, attr_name, cached_property(adder(attr_name)))
 
         return Grouper
 
@@ -917,15 +914,14 @@ class AssetDepreciationTable(CompanyReport):
 
             @cached_property
             def update_lines(self):
-                filter_ = lambda l: (l.account.kind == 'other'
+                filter_ = lambda l: (l.account.type.expense
                     and self.start_date < l.move.date <= self.end_date)
                 return list(filter(filter_,
                     (l for m in self.asset.update_moves for l in m.lines)))
 
             @cached_property
             def start_fixed_value(self):
-                if (self.start_date < self.asset.start_date
-                        or not self.asset_lines):
+                if self.start_date < self.asset.start_date:
                     return 0
                 value = self.asset_lines[0].acquired_value
                 date = self.asset_lines[0].date
@@ -1038,7 +1034,7 @@ class PrintDepreciationTable(Wizard):
         assets = Asset.search([
                 ('start_date', '<', self.start.end_date),
                 ('end_date', '>', self.start.start_date),
-                ('state', '!=', 'draft'),
+                ('state', '=', 'running'),
                 ])
         return action, {
             'ids': [a.id for a in assets],
